 %macro SCOREV2(MODEL);
 %***********************************************************************
 MACRO NAME:    SCOREV2
 PURPOSE:       Compute risk scores, one for each metal level
                Compute cost sharing reduction (CSR) adjusted risk scores, one 
                 for each metal level 
                Generate ONE risk score and ONE CSR adjusted risk score per 
                 enrollee                
 COMMENT:       Parameter MODEL in (ADULT,CHILD,INFANT)
 ***********************************************************************;
 
 %let INITIAL = %substr(&MODEL,1,1);
 
 %** zero scores **; 
 do i=1 to dim(_&MODEL._SCORES);
  _&MODEL._SCORES(i)=0;
 end;
 
 do i=1 to dim(_&MODEL._VARIABLES);
  SCORE_&MODEL._PLATINUM     = SCORE_&MODEL._PLATINUM     + 
   (_&MODEL._COEFFICIENTS_&INITIAL.P(i) * _&MODEL._VARIABLES(i));
  SCORE_&MODEL._GOLD         = SCORE_&MODEL._GOLD         + 
   (_&MODEL._COEFFICIENTS_&INITIAL.G(i) * _&MODEL._VARIABLES(i));        
  SCORE_&MODEL._SILVER       = SCORE_&MODEL._SILVER       + 
   (_&MODEL._COEFFICIENTS_&INITIAL.S(i) * _&MODEL._VARIABLES(i));        
  SCORE_&MODEL._BRONZE       = SCORE_&MODEL._BRONZE       + 
   (_&MODEL._COEFFICIENTS_&INITIAL.B(i) * _&MODEL._VARIABLES(i));         
  SCORE_&MODEL._CATASTROPHIC = SCORE_&MODEL._CATASTROPHIC + 
   (_&MODEL._COEFFICIENTS_&INITIAL.C(i) * _&MODEL._VARIABLES(i));
 end;
 
 %** cost sharing reduction (CSR) adjusted risk scores, one for each metal **;
 CSR_ADJ_SCR_&MODEL._PLATINUM     = SCORE_&MODEL._PLATINUM;
 CSR_ADJ_SCR_&MODEL._GOLD         = SCORE_&MODEL._GOLD;
 CSR_ADJ_SCR_&MODEL._SILVER       = SCORE_&MODEL._SILVER;
 CSR_ADJ_SCR_&MODEL._BRONZE       = SCORE_&MODEL._BRONZE;
 CSR_ADJ_SCR_&MODEL._CATASTROPHIC = SCORE_&MODEL._CATASTROPHIC;
 
 %** no adjustment for code points 0, 8, and x 1.00 cases (placeholders) **;
 if      CSR_INDICATOR = 0 then;
 else if CSR_INDICATOR = 1 then CSR_ADJ_SCR_&MODEL._SILVER   = 
  SCORE_&MODEL._SILVER   * 1.12;
 else if CSR_INDICATOR = 2 then CSR_ADJ_SCR_&MODEL._SILVER   = 
  SCORE_&MODEL._SILVER   * 1.12;
 else if CSR_INDICATOR = 3 then CSR_ADJ_SCR_&MODEL._SILVER   = 
  SCORE_&MODEL._SILVER   * 1.00;
 else if CSR_INDICATOR = 4 then CSR_ADJ_SCR_&MODEL._PLATINUM = 
  SCORE_&MODEL._PLATINUM * 1.15;
 else if CSR_INDICATOR = 5 then CSR_ADJ_SCR_&MODEL._GOLD     = 
  SCORE_&MODEL._GOLD     * 1.12;
 else if CSR_INDICATOR = 6 then CSR_ADJ_SCR_&MODEL._SILVER   = 
  SCORE_&MODEL._SILVER   * 1.07;
 else if CSR_INDICATOR = 7 then CSR_ADJ_SCR_&MODEL._BRONZE   = 
  SCORE_&MODEL._BRONZE   * 1.00;
 else if CSR_INDICATOR = 8 then;
 
 %** generate ONE risk score and ONE CSR adjusted risk score per enrollee **;
 select;
  when (METAL="P") do; 
   SCORE_&MODEL = SCORE_&MODEL._PLATINUM;     
   CSR_ADJ_SCR_&MODEL = CSR_ADJ_SCR_&MODEL._PLATINUM; 
  end;
  when (METAL="G") do; 
   SCORE_&MODEL = SCORE_&MODEL._GOLD;         
   CSR_ADJ_SCR_&MODEL = CSR_ADJ_SCR_&MODEL._GOLD; 
  end;
  when (METAL="S") do; 
   SCORE_&MODEL = SCORE_&MODEL._SILVER;       
   CSR_ADJ_SCR_&MODEL = CSR_ADJ_SCR_&MODEL._SILVER; 
  end;
  when (METAL="B") do; 
   SCORE_&MODEL = SCORE_&MODEL._BRONZE;       
   CSR_ADJ_SCR_&MODEL = CSR_ADJ_SCR_&MODEL._BRONZE; 
  end;
  when (METAL="C") do; 
   SCORE_&MODEL = SCORE_&MODEL._CATASTROPHIC; 
   CSR_ADJ_SCR_&MODEL = CSR_ADJ_SCR_&MODEL._CATASTROPHIC; 
  end;
  otherwise;
 end;
 %mend SCOREV2;